# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

__all__ = ["DeviceStageParams", "ConfigInstance"]


class DeviceStageParams(TypedDict, total=False):
    config_instances: Required[Iterable[ConfigInstance]]
    """The config instances to stage on the device.

    These config instances will be deployed to the device as soon as it is
    activated.
    """


class ConfigInstance(TypedDict, total=False):
    config_schema_id: Required[str]
    """The id of the config schema which this config instance must adhere to."""

    content: Required[object]
    """The configuration values associated with the config instance."""

    relative_filepath: Required[str]
    """
    The file path to deploy the config instance relative to
    `/srv/miru/config_instances`. `v1/motion-control.json` would deploy to
    `/srv/miru/config_instances/v1/motion-control.json`
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["Device"]


class Device(BaseModel):
    id: str
    """ID of the device"""

    created_at: datetime
    """Timestamp of when the device was created"""

    last_connected_at: Optional[datetime] = None
    """
    Timestamp of when the device was last made an initial connection (this is not
    the same as the last time the device was seen).
    """

    last_disconnected_at: Optional[datetime] = None
    """
    Timestamp of when the device was last disconnected (this is not the same as the
    last time the device was seen).
    """

    name: str
    """Name of the device"""

    object: Literal["device"]

    status: Literal["inactive", "staged", "activated", "online", "offline"]
    """The status of the device

    - Inactive: The miru agent has not yet been installed / authenticated
    - Staged: The device has been staged for activation
    - Activated: The miru agent has been installed and authenticated
    - Online: The miru agent has successfully pinged the server within the last 45
      seconds.
    - Offline: The miru agent has not successfully pinged the server within the last
      45 seconds (e.g. network issues, device is powered off, etc.)
    """

    updated_at: datetime
    """Timestamp of when the device was last updated"""



import os

from dotenv import load_dotenv

from miru_server_sdk import Miru

# set the MIRU_API_KEY environment variable in your '.env' file
# place this file in the /examples directory
load_dotenv()


def main() -> None:
    if not os.getenv("MIRU_API_KEY"):
        raise ValueError("MIRU_API_KEY is not set")

    client = Miru(api_key=os.getenv("MIRU_API_KEY"))

    device = client.devices.retrieve(
        device_id="dvc_MoU7XtRE4U5GuDAEHdTfyfXfswkjydioc"
    )
    print(device.to_json())


if __name__ == "__main__":
    main()
